/*

    This file defines the image generation parameters.
    Each range parameter is defined as follows:

    	typeRangeParam(name, dmin, dmax, umin, umax)
	
    where
    
    	type	    Variable type: Float or Int
	name	    Base variable name.  Values are stored in
	    	    variables named:
		    	name_min    Default minimum
			name_max    Default maximum
			name_umin   Minimum user specified value
			name_umax   Maxumum user specified value
	dmin	    Default minimum value
	dmax	    Default maximum value
	umin	    User specified minimum value
	umax	    User specified maximum value
	
    The actual value used in generation of an image will be
    a uniformly distributed pseudorandom value between the
    _min and _max limits for the variable.
    
*/

    /*	Parameter declaration macros  */

#define FloatParam(name, defval) Parameter(double, name, defval)
#define IntParam(name, defval) Parameter(int, name, defval)

#define RangeParam(type, name, minval, maxval, umin, umax) \
    Parameter(type, name##_min, minval); \
    Parameter(type, name##_max, maxval); \
    Parameter(const type, name##_umin, umin); \
    Parameter(const type, name##_umax, umax);
    
#define FloatRangeParam(name, minval, maxval, umin, umax) RangeParam(double, name, minval, maxval, umin, umax)

#define IntRangeParam(name, minval, maxval, umin, umax) RangeParam(int, name, minval, maxval, umin, umax)

    /* Fractal dimension of planetary landscape */
FloatRangeParam(fractal_dimension, 2.0, 2.7, 1.0, 3.0);
    /* Power spectrum of planetary landscape */
FloatRangeParam(power_spectrum, 1.0, 1.5, 0.1, 4.0);
    /* Polar icecap level */
FloatRangeParam(ice_level, 0.2, 0.6, 0.0, 1.0);
    /* Glacier level */
FloatRangeParam(glacier_level, 0.6, 0.85, 0.0, 1.0);

    /* Fractal dimension of clouds */
FloatRangeParam(fractal_dimension_clouds, 1.9, 2.3, 1.0, 3.0);
    /* Power spectrum of clouds */
FloatRangeParam(power_spectrum_clouds, 0.6, 0.8, 0.1, 4.0);

    /* Density of stars in night sky */
IntRangeParam(star_fraction, 50, 75, 0, 1000);
    /* Colour saturation of stars */
IntRangeParam(star_colour, 100, 150, 0, 1000);
    /* Number of star clusters */
IntRangeParam(star_clusters, -3, 1, -10000, MAX_STAR_CLUSTERS);
    /* Density of stars in clusters */
IntRangeParam(star_cluster_density, 10, 100, 0, 500);
    /* Width of star clusters */
IntRangeParam(star_cluster_width, 10, 30, 0, 200);

IntParam(show_planets, TRUE);	    /* Show planets ? */
IntParam(show_clouds, FALSE);	    /* Show cloudy sky ? */
IntParam(show_stars, FALSE);	    /* Show starry sky ? */
IntParam(hell, FALSE);	    	    /* Show Hell fire ? */
IntParam(blackhole, FALSE); 	    /* Show black hole ? */

IntParam(crescents, FALSE); 	    /* Allow extreme crescent planets */

IntParam(randomPosition, FALSE);    /* Randomly position pattern */

IntParam(screenX, 640);     	    /* Image width */
IntParam(screenY, 480);     	    /* Image height */
IntParam(mesh_size, 1024);  	    /* FFT mesh size */

IntParam(verbose, FALSE);   	    /* Verbose output ? */

FloatParam(star_size, 1.4); 	    /* Width of Gaussian point spread function
    	    	    	    	       for stars */
FloatParam(star_bright, 1.0);	    /* Star brightness adjustment factor */
FloatParam(star_gamma, 1.9);	    /* Gamma exponent for star brightness */
